@@ -7,7 +7,7 @@ use Text::ParseWords qw( shellwords );
 use Capture::Tiny qw( capture );
 
 # ABSTRACT: Alien::Build command sequence
-our $VERSION = '2.58_01'; # TRIAL VERSION
+our $VERSION = '2.60_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -135,8 +135,6 @@ sub execute
   my($self, $build) = @_;
   my $intr = $build->meta->interpolator;
 
-  my $prop = $build->_command_prop;
-
   foreach my $command (@{ $self->{commands} })
   {
     if(ref($command) eq 'CODE')
@@ -161,7 +159,7 @@ sub execute
             die "external command failed" if $args->{exit};
             my $out = $args->{out};
             chomp $out;
-            _apply($dest, $prop, $out);
+            _apply($dest, $build->_command_prop, $out);
           };
         }
         else
@@ -170,7 +168,7 @@ sub execute
         }
       }
 
-      ($command, @args) = map { $intr->interpolate($_, $prop) } ($command, @args);
+      ($command, @args) = map { $intr->interpolate($_, $build) } ($command, @args);
 
       if($code)
       {
@@ -183,7 +181,7 @@ sub execute
     }
     else
     {
-      my $command = $intr->interpolate($command,$prop);
+      my $command = $intr->interpolate($command, $build);
       _run_string $build, $command;
     }
   }
@@ -203,7 +201,7 @@ Alien::Build::CommandSequence - Alien::Build command sequence
 
 =head1 VERSION
 
-version 2.58_01
+version 2.60_01
 
 =head1 CONSTRUCTOR
 
