@@ -5,7 +5,7 @@ use warnings;
 use 5.008004;
 
 # ABSTRACT: Advanced interpolation engine for Alien builds
-our $VERSION = '2.58_01'; # TRIAL VERSION
+our $VERSION = '2.60_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -157,16 +157,11 @@ sub _get_prop
 
 sub interpolate
 {
-  my($self, $string, $prop) = @_;
+  my($self, $string, $build) = @_;
 
-  if(eval { $prop->isa('Alien::Build') })
-  {
-    $prop = $prop->_command_prop;
-  }
-  else
-  {
-    $prop ||= {};
-  }
+  my $prop = defined $build && eval { $build->isa('Alien::Build') }
+  ? $build->_command_prop
+  : {};
 
   $string =~ s{(?<!\%)\%\{([a-zA-Z_][a-zA-Z_0-9]+)\}}{$self->execute_helper($1)}eg;
   $string =~ s{(?<!\%)\%\{([a-zA-Z_\.][a-zA-Z_0-9\.]+)\}}{_get_prop($1,$prop,$1)}eg;
@@ -259,7 +254,7 @@ Alien::Build::Interpolate - Advanced interpolation engine for Alien builds
 
 =head1 VERSION
 
-version 2.58_01
+version 2.60_01
 
 =head1 CONSTRUCTOR
 
@@ -303,7 +298,7 @@ in the template.
 If you pass in an L<Alien::Build> instance as the second argument, you can use
 properties as well as helpers in the template.  Example:
 
- my $patch = $intr->template("%{.install.patch}/foo-%{.runtime.version}.patch");
+ my $patch = $intr->template("%{.install.patch}/foo-%{.runtime.version}.patch", $build);
 
 =head2 requires
 
