@@ -8,7 +8,7 @@ use Path::Tiny ();
 use Alien::Build::Util qw( _mirror );
 
 # ABSTRACT: Core download plugin
-our $VERSION = '2.58_01'; # TRIAL VERSION
+our $VERSION = '2.60_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -29,9 +29,22 @@ sub _hook
   if($res->{type} eq 'list')
   {
     $res = $build->prefer($res);
+
+    my @exclude;
+    if($build->meta->prop->{start_url} =~ /^https:/)
+    {
+      @{ $res->{list} } = grep {
+        $_->{url} =~ /https:/ ? 1 : do {
+          push @exclude, $_->{url};
+          0;
+        }
+      } @{ $res->{list} };
+    }
+
     die "no matching files in listing" if @{ $res->{list} } == 0;
     my $version = $res->{list}->[0]->{version};
     my($pick, @other) = map { $_->{url} } @{ $res->{list} };
+
     if(@other > 8)
     {
       splice @other, 7;
@@ -39,6 +52,18 @@ sub _hook
     }
     $build->log("candidate *$pick");
     $build->log("candidate  $_") for @other;
+
+    if(@exclude)
+    {
+      if(@exclude > 8)
+      {
+        splice @exclude, 7;
+        push @exclude, '...';
+      }
+      $build->log("excluded insecure URLs:");
+      $build->log($_) for @exclude;
+    }
+
     $res = $build->fetch($pick);
 
     if($version)
@@ -60,6 +85,7 @@ sub _hook
       $path->spew_raw($res->{content});
       $build->install_prop->{download} = $path->stringify;
       $build->install_prop->{complete}->{download} = 1;
+      $build->install_prop->{download_detail}->{"$path"}->{protocol} = $res->{protocol} if defined $res->{protocol};
       return $build;
     }
     elsif($res->{path})
@@ -70,6 +96,7 @@ sub _hook
         {
           $build->install_prop->{download} = $res->{path};
           $build->install_prop->{complete}->{download} = 1;
+          $build->install_prop->{download_detail}->{$res->{path}}->{protocol} = $res->{protocol} if defined $res->{protocol};
         }
         else
         {
@@ -98,6 +125,7 @@ sub _hook
         }
         $build->install_prop->{download} = $to->stringify;
         $build->install_prop->{complete}->{download} = 1;
+        $build->install_prop->{download_detail}->{"$to"}->{protocol} = $res->{protocol} if defined $res->{protocol};
       }
       return $build;
     }
@@ -127,7 +155,7 @@ Alien::Build::Plugin::Core::Download - Core download plugin
 
 =head1 VERSION
 
-version 2.58_01
+version 2.60_01
 
 =head1 SYNOPSIS
 
