@@ -9,7 +9,7 @@ use Alien::Build::Util qw( _ssl_reqs );
 use Carp ();
 
 # ABSTRACT: Plugin for fetching files using HTTP::Tiny
-our $VERSION = '2.58_01'; # TRIAL VERSION
+our $VERSION = '2.60_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -45,6 +45,8 @@ sub init
     my($build, $url, %options) = @_;
     $url ||= $self->url;
 
+    $url = URI->new($url) unless ref($url) && $url->isa('URI');
+
     my %headers;
     if(my $headers = $options{http_headers})
     {
@@ -120,9 +122,10 @@ sub init
     if($type eq 'text/html')
     {
       return {
-        type    => 'html',
-        base    => $base->as_string,
-        content => $res->{content},
+        type     => 'html',
+        base     => $base->as_string,
+        content  => $res->{content},
+        protocol => $url->scheme,
       };
     }
     else
@@ -131,6 +134,7 @@ sub init
         type     => 'file',
         filename => $filename || 'downloadedfile',
         content  => $res->{content},
+        protocol => $url->scheme,
       };
     }
 
@@ -153,7 +157,7 @@ Alien::Build::Plugin::Fetch::HTTPTiny - Plugin for fetching files using HTTP::Ti
 
 =head1 VERSION
 
-version 2.58_01
+version 2.60_01
 
 =head1 SYNOPSIS
 
