@@ -7,7 +7,7 @@ use Alien::Build::Plugin;
 use Carp ();
 
 # ABSTRACT: Plugin for fetching files using LWP
-our $VERSION = '2.58_01'; # TRIAL VERSION
+our $VERSION = '2.60_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -52,6 +52,8 @@ sub init
     $ua->env_proxy;
     my $res = $ua->get($url, @headers);
 
+    my($protocol) = $url =~ /^([a-z]+):/;
+
     die "error fetching $url: @{[ $res->status_line ]}"
       unless $res->is_success;
 
@@ -62,18 +64,20 @@ sub init
     if($type eq 'text/html')
     {
       return {
-        type    => 'html',
-        charset => $charset,
-        base    => "$base",
-        content => $res->decoded_content || $res->content,
+        type     => 'html',
+        charset  => $charset,
+        base     => "$base",
+        content  => $res->decoded_content || $res->content,
+        protocol => $protocol,
       };
     }
     elsif($type eq 'text/ftp-dir-listing')
     {
       return {
-        type => 'dir_listing',
-        base => "$base",
-        content => $res->decoded_content || $res->content,
+        type     => 'dir_listing',
+        base     => "$base",
+        content  => $res->decoded_content || $res->content,
+        protocol => $protocol,
       };
     }
     else
@@ -82,6 +86,7 @@ sub init
         type     => 'file',
         filename => $filename || 'downloadedfile',
         content  => $res->content,
+        protocol => $protocol,
       };
     }
 
@@ -104,7 +109,7 @@ Alien::Build::Plugin::Fetch::LWP - Plugin for fetching files using LWP
 
 =head1 VERSION
 
-version 2.58_01
+version 2.60_01
 
 =head1 SYNOPSIS
 
