@@ -11,7 +11,7 @@ use Carp ();
 sub _path { Path::Tiny::path(@_) }
 
 # ABSTRACT: Specification for defining an external dependency for CPAN
-our $VERSION = '2.58_01'; # TRIAL VERSION
+our $VERSION = '2.60_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -380,7 +380,7 @@ alienfile - Specification for defining an external dependency for CPAN
 
 =head1 VERSION
 
-version 2.58_01
+version 2.60_01
 
 =head1 SYNOPSIS
 
@@ -730,7 +730,7 @@ Get the meta_prop hash reference.
  my $meta = meta;
 
 Returns the meta object for your L<alienfile>.  For methods that can be used on the
-meta object, see L<Alien::Build/META-METHODS>.
+meta object, see L<Alien::Build/"META METHODS">.
 
 =head2 log
 
